import os
import re


class lfcrlf:
    
    @staticmethod
    def __fileconvert(dir: str, point: str) -> None:
        try:
            with open(dir, "rb") as file:
                content = file.read()
            if point == "lf":
                content = re.sub(b'(?<!\r)\n', b'\r\n', content)
            elif point == "crlf":
                content = content.replace(b'\r\n', b'\n')

            with open(dir, "wb") as file:
                file.write(content)
                
        except Exception as e:
            print(f"Error processing file {dir}: {str(e)}")

    @staticmethod
    def __dir_recursion(dir_path: str, point: str) -> None:
        try:
            dirlist = os.listdir(dir_path)
        except PermissionError:
            print(f"No access to folder: {dir_path}")
            return
            
        for file in dirlist:
            full_path = os.path.join(dir_path, file)
            if os.path.isdir(full_path):
                lfcrlf.__dir_recursion(full_path, point)  # Исправлено
            else:
                if file.endswith(('.txt', '.py', '.html', '.css', 
                                '.js', '.json', '.xml', '.md')):
                    lfcrlf.__fileconvert(full_path, point)  # Исправлено

    @staticmethod
    def convert_dir(dir_path: str, point: str) -> None:
        lfcrlf.__dir_recursion(dir_path, point)

    @staticmethod
    def convert_file(file_path: str, point: str) -> None:
        lfcrlf.__fileconvert(file_path, point)
                
def convert_dir(dir_path: str, point: str) -> None:
    abs_path = os.path.abspath(dir_path)
    lfcrlf.convert_dir(abs_path, point)

def convert_file(file_path: str, point: str) -> None:
    abs_path = os.path.abspath(file_path)
    lfcrlf.convert_file(abs_path, point)


from setuptools import setup, find_packages

def readme():
    with open('README.md', 'r', encoding='utf-8') as f:
        return f.read()

setup(
    name='lf-crlf',
    version='0.0.1',
    author='farfromsouls',
    author_email='farfromsouls@gmail.com',
    description='A tool to convert line endings between LF and CRLF',
    long_description=readme(),
    long_description_content_type='text/markdown',
    url='https://github.com/farfromsouls/LF_CRLF',
    packages=find_packages(),
    install_requires=[],
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities'
    ],
    keywords='line endings lf crlf convert text files',
    project_urls={
        'GitHub': 'https://github.com/farfromsouls/LF_CRLF',
        'Bug Reports': 'https://github.com/farfromsouls/LF_CRLF/issues',
    },
    python_requires='>=3.6'
)